from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Float, Int, String, Boolean, File, Directory

Crispressobatch_V0_1_0 = CommandToolBuilder(tool="CRISPRessoBatch", base_command=["CRISPRessoBatch"], inputs=[ToolInput(tag="in_analysis", input_type=Float(optional=True), prefix="-Analysis", doc=InputDocumentation(doc="CRISPR/Cas9 outcomes from batch deep sequencing data-\n_                                             _\n'  )                                          '  )\n.-'            _________________              .-'\n(____          | __    ___ __    |            (____\nC)|     \         ||__) /\ | /  |__||         C)|     \\n\     /         ||__)/--\| \__|  ||           \     /\n\___/          |_________________|            \___/\n[CRISPResso version 2.1.0]")), ToolInput(tag="in_fast_q_r_one", input_type=Int(optional=True), prefix="--fastq_r1", doc=InputDocumentation(doc="First fastq file (default: )")), ToolInput(tag="in_fast_q_r_two", input_type=Int(optional=True), prefix="--fastq_r2", doc=InputDocumentation(doc="Second fastq file for paired end reads (default: )")), ToolInput(tag="in_amplicon_seq", input_type=String(optional=True), prefix="--amplicon_seq", doc=InputDocumentation(doc="Amplicon Sequence (can be comma-separated list of\nmultiple sequences) (default: None)")), ToolInput(tag="in_amplicon_name", input_type=String(optional=True), prefix="--amplicon_name", doc=InputDocumentation(doc="Amplicon Name (can be comma-separated list of multiple\nnames, corresponding to amplicon sequences given in\n--amplicon_seq (default: Reference)")), ToolInput(tag="in_amplicon_min_alignment_score", input_type=Int(optional=True), prefix="--amplicon_min_alignment_score", doc=InputDocumentation(doc="Amplicon Minimum Alignment Score; score between 0 and\n100; sequences must have at least this homology score\nwith the amplicon to be aligned (can be comma-\nseparated list of multiple scores, corresponding to\namplicon sequences given in --amplicon_seq) (default:\n)")), ToolInput(tag="in_default_min_aln_score", input_type=Int(optional=True), prefix="--default_min_aln_score", doc=InputDocumentation(doc="Default minimum homology score for a read to align to\na reference amplicon (default: 60)")), ToolInput(tag="in_expand_ambiguous_alignments", input_type=Boolean(optional=True), prefix="--expand_ambiguous_alignments", doc=InputDocumentation(doc="If more than one reference amplicon is given, reads\nthat align to multiple reference amplicons will count\nequally toward each amplicon. Default behavior is to\nexclude ambiguous alignments. (default: False)")), ToolInput(tag="in_guide_seq", input_type=Int(optional=True), prefix="--guide_seq", doc=InputDocumentation(doc="sgRNA sequence, if more than one, please separate by\ncommas. Note that the sgRNA needs to be input as the\nguide RNA sequence (usually 20 nt) immediately\nadjacent to but not including the PAM sequence (5' of\nNGG for SpCas9). If the PAM is found on the opposite\nstrand with respect to the Amplicon Sequence, ensure\nthe sgRNA sequence is also found on the opposite\nstrand. The CRISPResso convention is to depict the\nexpected cleavage position using the value of the\nparameter '--quantification_window_center' nucleotides\nfrom the 3' end of the guide. In addition, the use of\nalternate nucleases besides SpCas9 is supported. For\nexample, if using the Cpf1 system, enter the sequence\n(usually 20 nt) immediately 3' of the PAM sequence and\nexplicitly set the '--cleavage_offset' parameter to 1,\nsince the default setting of -3 is suitable only for\nSpCas9. (default: )")), ToolInput(tag="in_guide_name", input_type=String(optional=True), prefix="--guide_name", doc=InputDocumentation(doc="sgRNA names, if more than one, please separate by\ncommas. (default: )")), ToolInput(tag="in_flexi_guide_seq", input_type=String(optional=True), prefix="--flexiguide_seq", doc=InputDocumentation(doc="sgRNA sequence (flexible) (can be comma-separated list\nof multiple flexiguides). The flexiguide sequence will\nbe aligned to the amplicon sequence(s), as long as the\nguide sequence has homology as set by\n--flexiguide_homology. (default: None)")), ToolInput(tag="in_flexi_guide_homology", input_type=Int(optional=True), prefix="--flexiguide_homology", doc=InputDocumentation(doc="flexiguides will yield guides in amplicons with at\nleast this homology to the flexiguide sequence.\n(default: 80)")), ToolInput(tag="in_flexi_guide_name", input_type=String(optional=True), prefix="--flexiguide_name", doc=InputDocumentation(doc="flexiguide name (default: )")), ToolInput(tag="in_discard_guide_positions_overhanging_amplicon_edge", input_type=Boolean(optional=True), prefix="--discard_guide_positions_overhanging_amplicon_edge", doc=InputDocumentation(doc="If set, for guides that align to multiple positions,\nguide positions will be discarded if plotting around\nthose regions would included bp that extend beyond the\nend of the amplicon. (default: False)")), ToolInput(tag="in_expected_hdr_amplicon_seq", input_type=String(optional=True), prefix="--expected_hdr_amplicon_seq", doc=InputDocumentation(doc="Amplicon sequence expected after HDR (default: )")), ToolInput(tag="in_coding_seq", input_type=String(optional=True), prefix="--coding_seq", doc=InputDocumentation(doc="Subsequence/s of the amplicon sequence covering one or\nmore coding sequences for frameshift analysis. If more\nthan one (for example, split by intron/s), please\nseparate by commas. (default: )")), ToolInput(tag="in_min_average_read_quality", input_type=Int(optional=True), prefix="--min_average_read_quality", doc=InputDocumentation(doc="Minimum average quality score (phred33) to keep a read\n(default: 0)")), ToolInput(tag="in_min_single_bp_quality", input_type=Int(optional=True), prefix="--min_single_bp_quality", doc=InputDocumentation(doc="Minimum single bp score (phred33) to keep a read\n(default: 0)")), ToolInput(tag="in_min_bp_quality_or_n", input_type=Int(optional=True), prefix="--min_bp_quality_or_N", doc=InputDocumentation(doc="Bases with a quality score (phred33) less than this\nvalue will be set to 'N' (default: 0)")), ToolInput(tag="in_file_prefix", input_type=File(optional=True), prefix="--file_prefix", doc=InputDocumentation(doc="File prefix for output plots and tables (default: )")), ToolInput(tag="in_name", input_type=File(optional=True), prefix="--name", doc=InputDocumentation(doc="Output name of the report (default: the name is\nobtained from the filename of the fastq file/s used in\ninput) (default: )")), ToolInput(tag="in_output_folder", input_type=Directory(optional=True), prefix="--output_folder", doc=InputDocumentation(doc="Output folder to use for the analysis (default:\ncurrent folder) (default: )")), ToolInput(tag="in_split_interleaved_input", input_type=Boolean(optional=True), prefix="--split_interleaved_input", doc=InputDocumentation(doc="Splits a single fastq file containing paired end reads\ninto two files before running CRISPResso (default:\nFalse)")), ToolInput(tag="in_trim_sequences", input_type=Boolean(optional=True), prefix="--trim_sequences", doc=InputDocumentation(doc="Enable the trimming of Illumina adapters with\nTrimmomatic (default: False)")), ToolInput(tag="in_trim_mo_matic_command", input_type=String(optional=True), prefix="--trimmomatic_command", doc=InputDocumentation(doc="Command to run trimmomatic (default: trimmomatic)")), ToolInput(tag="in_trim_mo_matic_options_string", input_type=Int(optional=True), prefix="--trimmomatic_options_string", doc=InputDocumentation(doc="Override options for Trimmomatic, e.g.\n'ILLUMINACLIP:/data/NexteraPE-PE.fa:0:90:10:0:true'\n(default: )")), ToolInput(tag="in_flash_command", input_type=String(optional=True), prefix="--flash_command", doc=InputDocumentation(doc="Command to run flash (default: flash)")), ToolInput(tag="in_min_paired_end_reads_overlap", input_type=Int(optional=True), prefix="--min_paired_end_reads_overlap", doc=InputDocumentation(doc="Parameter for the FLASH read merging step. Minimum\nrequired overlap length between two reads to provide a\nconfident overlap. (default: 10)")), ToolInput(tag="in_max_paired_end_reads_overlap", input_type=Int(optional=True), prefix="--max_paired_end_reads_overlap", doc=InputDocumentation(doc="Parameter for the FLASH merging step. Maximum overlap\nlength expected in approximately 90% of read pairs.\nPlease see the FLASH manual for more information.\n(default: 100)")), ToolInput(tag="in_stringent_flash_merging", input_type=Boolean(optional=True), prefix="--stringent_flash_merging", doc=InputDocumentation(doc="Use stringent parameters for flash merging. In the\ncase where flash could merge R1 and R2 reads\nambiguously, the expected overlap is calculated as\n2*average_read_length - amplicon_length. The flash\nparameters for --min-overlap and --max-overlap will be\nset to prefer merged reads with length within 10bp of\nthe expected overlap. These values override the\n--min_paired_end_reads_overlap or\n--max_paired_end_reads_overlap CRISPResso parameters.\n(default: False)")), ToolInput(tag="in_quantification_window_size", input_type=Int(optional=True), prefix="--quantification_window_size", doc=InputDocumentation(doc="Defines the size (in bp) of the quantification window\nextending from the position specified by the '--\ncleavage_offset' or '--quantification_window_center'\nparameter in relation to the provided guide RNA\nsequence(s) (--sgRNA). Mutations within this number of\nbp from the quantification window center are used in\nclassifying reads as modified or unmodified. A value\nof 0 disables this window and indels in the entire\namplicon are considered. Default is 1, 1bp on each\nside of the cleavage position for a total length of\n2bp. Multiple quantification window sizes\n(corresponding to each guide specified by --guide_seq)\ncan be specified with a comma-separated list.\n(default: 1)")), ToolInput(tag="in_quantification_window_center", input_type=Int(optional=True), prefix="--quantification_window_center", doc=InputDocumentation(doc="Center of quantification window to use within respect\nto the 3' end of the provided sgRNA sequence. Remember\nthat the sgRNA sequence must be entered without the\nPAM. For cleaving nucleases, this is the predicted\ncleavage position. The default is -3 and is suitable\nfor the Cas9 system. For alternate nucleases, other\ncleavage offsets may be appropriate, for example, if\nusing Cpf1 this parameter would be set to 1. For base\neditors, this could be set to -17 to only include\nmutations near the 5' end of the sgRNA. Multiple\nquantification window centers (corresponding to each\nguide specified by --guide_seq) can be specified with\na comma-separated list. (default: -3)")), ToolInput(tag="in_exclude_bp_from_left", input_type=Int(optional=True), prefix="--exclude_bp_from_left", doc=InputDocumentation(doc="Exclude bp from the left side of the amplicon sequence\nfor the quantification of the indels (default: 15)")), ToolInput(tag="in_exclude_bp_from_right", input_type=Int(optional=True), prefix="--exclude_bp_from_right", doc=InputDocumentation(doc="Exclude bp from the right side of the amplicon\nsequence for the quantification of the indels\n(default: 15)")), ToolInput(tag="in_use_legacy_insertion_quantification", input_type=Boolean(optional=True), prefix="--use_legacy_insertion_quantification", doc=InputDocumentation(doc="If set, the legacy insertion quantification method\nwill be used (i.e. with a 1bp quantification window,\nindels at the cut site and 1bp away from the cut site\nwould be quantified). By default (if this parameter is\nnot set) with a 1bp quantification window, only\ninsertions at the cut site will be quantified.\n(default: False)")), ToolInput(tag="in_ignore_substitutions", input_type=Boolean(optional=True), prefix="--ignore_substitutions", doc=InputDocumentation(doc="Ignore substitutions events for the quantification and\nvisualization (default: False)")), ToolInput(tag="in_ignore_insertions", input_type=Boolean(optional=True), prefix="--ignore_insertions", doc=InputDocumentation(doc="Ignore insertions events for the quantification and\nvisualization (default: False)")), ToolInput(tag="in_ignore_deletions", input_type=Boolean(optional=True), prefix="--ignore_deletions", doc=InputDocumentation(doc="Ignore deletions events for the quantification and\nvisualization (default: False)")), ToolInput(tag="in_discard_in_del_reads", input_type=Boolean(optional=True), prefix="--discard_indel_reads", doc=InputDocumentation(doc="Discard reads with indels in the quantification window\nfrom analysis (default: False)")), ToolInput(tag="in_needleman_wunsch_gap_open", input_type=Int(optional=True), prefix="--needleman_wunsch_gap_open", doc=InputDocumentation(doc="Gap open option for Needleman-Wunsch alignment\n(default: -20)")), ToolInput(tag="in_needleman_wunsch_gap_extend", input_type=Int(optional=True), prefix="--needleman_wunsch_gap_extend", doc=InputDocumentation(doc="Gap extend option for Needleman-Wunsch alignment\n(default: -2)")), ToolInput(tag="in_needleman_wunsch_gap_incentive", input_type=Int(optional=True), prefix="--needleman_wunsch_gap_incentive", doc=InputDocumentation(doc="Gap incentive value for inserting indels at cut sites\n(default: 1)")), ToolInput(tag="in_needleman_wunsch_aln_matrix_loc", input_type=String(optional=True), prefix="--needleman_wunsch_aln_matrix_loc", doc=InputDocumentation(doc="Location of the matrix specifying substitution scores\nin the NCBI format (see\nftp://ftp.ncbi.nih.gov/blast/matrices/) (default:\nEDNAFULL)")), ToolInput(tag="in_plot_histogram_outliers", input_type=Boolean(optional=True), prefix="--plot_histogram_outliers", doc=InputDocumentation(doc="If set, all values will be shown on histograms. By\ndefault (if unset), histogram ranges are limited to\nplotting data within the 99 percentile. (default:\nFalse)")), ToolInput(tag="in_offset_around_cut_to_plot", input_type=Int(optional=True), prefix="--offset_around_cut_to_plot", doc=InputDocumentation(doc="Defines the size of the window extending from the\nquantification window center to plot. Nucleotides\nwithin plot_window_size of the\nquantification_window_center for each guide are\nplotted. (default: 20)")), ToolInput(tag="in_min_frequency_alleles_around_cut_to_plot", input_type=Int(optional=True), prefix="--min_frequency_alleles_around_cut_to_plot", doc=InputDocumentation(doc="Minimum % reads required to report an allele in the\nalleles table plot. (default: 0.2)")), ToolInput(tag="in_expand_allele_plots_by_quantification", input_type=Boolean(optional=True), prefix="--expand_allele_plots_by_quantification", doc=InputDocumentation(doc="If set, alleles with different modifications in the\nquantification window (but not necessarily in the\nplotting window (e.g. for another sgRNA)) are plotted\non separate lines, even though they may have the same\napparent sequence. To force the allele plot and the\nallele table to be the same, set this parameter. If\nunset, all alleles with the same sequence will be\ncollapsed into one row. (default: False)")), ToolInput(tag="in_allele_plot_pcts_only_for_assigned_reference", input_type=Boolean(optional=True), prefix="--allele_plot_pcts_only_for_assigned_reference", doc=InputDocumentation(doc="If set, in the allele plots, the percentages will show\nthe percentage as a percent of reads aligned to the\nassigned reference. Default behavior is to show\npercentage as a percent of all reads. (default: False)")), ToolInput(tag="in_quantification_window_coordinates", input_type=Int(optional=True), prefix="--quantification_window_coordinates", doc=InputDocumentation(doc="Bp positions in the amplicon sequence specifying the\nquantification window. This parameter overrides values\nof the '--quantification_window_center', '--\ncleavage_offset', '--window_around_sgrna' or '--\nwindow_around_sgrna' values. Any indels/substitutions\noutside this window are excluded. Indexes are 0-based,\nmeaning that the first nucleotide is position 0.\nRanges are separted by the dash sign (e.g. 'start-\nstop'), and multiple ranges can be separated by the\nunderscore (_). A value of 0 disables this filter.\n(can be comma-separated list of values, corresponding\nto amplicon sequences given in --amplicon_seq e.g.\n5-10,5-10_20-30 would specify the 5th-10th bp in the\nfirst reference and the 5th-10th and 20th-30th bp in\nthe second reference) (default: None)")), ToolInput(tag="in_annotate_wild_type_allele", input_type=String(optional=True), prefix="--annotate_wildtype_allele", doc=InputDocumentation(doc="Wildtype alleles in the allele table plots will be\nmarked with this string (e.g. **). (default: )")), ToolInput(tag="in_keep_intermediate", input_type=Boolean(optional=True), prefix="--keep_intermediate", doc=InputDocumentation(doc="Keep all the intermediate files (default: False)")), ToolInput(tag="in_dump", input_type=Boolean(optional=True), prefix="--dump", doc=InputDocumentation(doc="Dump numpy arrays and pandas dataframes to file for\ndebugging purposes (default: False)")), ToolInput(tag="in_write_detailed_allele_table", input_type=Boolean(optional=True), prefix="--write_detailed_allele_table", doc=InputDocumentation(doc="If set, a detailed allele table will be written\nincluding alignment scores for each read sequence.\n(default: False)")), ToolInput(tag="in_fast_q_output", input_type=Boolean(optional=True), prefix="--fastq_output", doc=InputDocumentation(doc="If set, a fastq file with annotations for each read\nwill be produced. (default: False)")), ToolInput(tag="in_max_rows_alleles_around_cut_to_plot", input_type=Int(optional=True), prefix="--max_rows_alleles_around_cut_to_plot", doc=InputDocumentation(doc="Maximum number of rows to report in the alleles table\nplot. (default: 50)")), ToolInput(tag="in_suppress_report", input_type=Boolean(optional=True), prefix="--suppress_report", doc=InputDocumentation(doc="Suppress output report (default: False)")), ToolInput(tag="in_place_report_in_output_folder", input_type=Directory(optional=True), prefix="--place_report_in_output_folder", doc=InputDocumentation(doc="If true, report will be written inside the CRISPResso\noutput folder. By default, the report will be written\none directory up from the report output. (default:\nFalse)")), ToolInput(tag="in_suppress_plots", input_type=Boolean(optional=True), prefix="--suppress_plots", doc=InputDocumentation(doc="Suppress output plots (default: False)")), ToolInput(tag="in_base_editor_output", input_type=Boolean(optional=True), prefix="--base_editor_output", doc=InputDocumentation(doc="Outputs plots and tables to aid in analysis of base\neditor studies. (default: False)")), ToolInput(tag="in_conversion_nuc_from", input_type=String(optional=True), prefix="--conversion_nuc_from", doc=InputDocumentation(doc="For base editor plots, this is the nucleotide targeted\nby the base editor (default: C)")), ToolInput(tag="in_conversion_nuc_to", input_type=String(optional=True), prefix="--conversion_nuc_to", doc=InputDocumentation(doc="For base editor plots, this is the nucleotide produced\nby the base editor (default: T)")), ToolInput(tag="in_prime_editing_peg_rna_spacer_seq", input_type=Int(optional=True), prefix="--prime_editing_pegRNA_spacer_seq", doc=InputDocumentation(doc="pegRNA spacer sgRNA sequence used in prime editing.\nThe spacer should not include the PAM sequence. The\nsequence should be given in the RNA 5'->3' order, so\nfor Cas9, the PAM would be on the right side of the\ngiven sequence. (default: )")), ToolInput(tag="in_prime_editing_peg_rna_extension_seq", input_type=Int(optional=True), prefix="--prime_editing_pegRNA_extension_seq", doc=InputDocumentation(doc="Extension sequence used in prime editing. The sequence\nshould be given in the RNA 5'->3' order, such that the\nsequence starts with the RT template including the\nedit, followed by the Primer-binding site (PBS).\n(default: )")), ToolInput(tag="in_prime_editing_peg_rna_extension_quantification_window_size", input_type=Int(optional=True), prefix="--prime_editing_pegRNA_extension_quantification_window_size", doc=InputDocumentation(doc="Quantification window size (in bp) at flap site for\nmeasuring modifications anchored at the right side of\nthe extension sequence. Similar to the\n--quantification_window parameter, the total length of\nthe quantification window will be 2x this parameter.\nDefault: 5bp (10bp total window size) (default: 5)")), ToolInput(tag="in_prime_editing_peg_rna_scaffold_seq", input_type=Int(optional=True), prefix="--prime_editing_pegRNA_scaffold_seq", doc=InputDocumentation(doc="If given, reads containing any of this scaffold\nsequence before extension sequence (provided by\n--prime_editing_extension_seq) will be classified as\n'Scaffold-incorporated'. The sequence should be given\nin the 5'->3' order such that the RT template directly\nfollows this sequence. A common value is\n'GGCACCGAGUCGGUGC'. (default: )")), ToolInput(tag="in_prime_editing_peg_rna_scaffold_min_match_length", input_type=Int(optional=True), prefix="--prime_editing_pegRNA_scaffold_min_match_length", doc=InputDocumentation(doc="Minimum number of bases matching scaffold sequence for\nthe read to be counted as 'Scaffold-incorporated'. If\nthe scaffold sequence matches the reference sequence\nat the incorporation site, the minimum number of bases\nto match will be minimally increased (beyond this\nparameter) to disambiguate between prime-edited and\nscaffold-incorporated sequences. (default: 1)")), ToolInput(tag="in_prime_editing_nicking_guide_seq", input_type=Int(optional=True), prefix="--prime_editing_nicking_guide_seq", doc=InputDocumentation(doc="Nicking sgRNA sequence used in prime editing. The\nsgRNA should not include the PAM sequence. The\nsequence should be given in the RNA 5'->3' order, so\nfor Cas9, the PAM would be on the right side of the\nsequence (default: )")), ToolInput(tag="in_prime_editing_override_prime_edited_ref_seq", input_type=String(optional=True), prefix="--prime_editing_override_prime_edited_ref_seq", doc=InputDocumentation(doc="If given, this sequence will be used as the prime-\nedited reference sequence. This may be useful if the\nprime-edited reference sequence has large indels or\nthe algorithm cannot otherwise infer the correct\nreference sequence. (default: )")), ToolInput(tag="in_cris_presso_one_mode", input_type=Boolean(optional=True), prefix="--crispresso1_mode", doc=InputDocumentation(doc="Parameter usage as in CRISPResso 1 (default: False)")), ToolInput(tag="in_dso_dn", input_type=String(optional=True), prefix="--dsODN", doc=InputDocumentation(doc="Label reads with the dsODN sequence provided (default:\n)")), ToolInput(tag="in_auto", input_type=Boolean(optional=True), prefix="--auto", doc=InputDocumentation(doc="Infer amplicon sequence from most common reads\n(default: False)")), ToolInput(tag="in_debug", input_type=Boolean(optional=True), prefix="--debug", doc=InputDocumentation(doc="Show debug messages (default: False)")), ToolInput(tag="in_no_rerun", input_type=Boolean(optional=True), prefix="--no_rerun", doc=InputDocumentation(doc="Don't rerun CRISPResso2 if a run using the same\nparameters has already been finished. (default: False)")), ToolInput(tag="in_bam_input", input_type=String(optional=True), prefix="--bam_input", doc=InputDocumentation(doc="Aligned reads for processing in bam format (default: )")), ToolInput(tag="in_bam_chr_loc", input_type=Int(optional=True), prefix="--bam_chr_loc", doc=InputDocumentation(doc="Chromosome location in bam for reads to process. For\nexample: 'chr1:50-100' or 'chrX'. (default: )")), ToolInput(tag="in_batch_settings", input_type=File(optional=True), prefix="--batch_settings", doc=InputDocumentation(doc="Settings file for batch. Must be tab-separated text\nfile. The header row contains CRISPResso parameters\n(e.g., fastq_r1, fastq_r2, amplicon_seq, and other\noptional parameters). Each following row sets\nparameters for an additional batch. (default: None)")), ToolInput(tag="in_skip_failed", input_type=Boolean(optional=True), prefix="--skip_failed", doc=InputDocumentation(doc="Continue with batch analysis even if one sample fails\n(default: False)")), ToolInput(tag="in_min_reads_for_inclusion", input_type=Int(optional=True), prefix="--min_reads_for_inclusion", doc=InputDocumentation(doc="Minimum number of reads for a batch to be included in\nthe batch summary (default: 0)")), ToolInput(tag="in_n_processes", input_type=Int(optional=True), prefix="--n_processes", doc=InputDocumentation(doc="Specify the number of processes to use for\nquantification. Please use with caution since\nincreasing this parameter will increase the memory\nrequired to run CRISPResso. (default: 1)")), ToolInput(tag="in_batch_output_folder", input_type=Directory(optional=True), prefix="--batch_output_folder", doc=InputDocumentation(doc="Directory where batch analysis output will be stored\n(default: None)")), ToolInput(tag="in_cris_presso_command", input_type=String(optional=True), prefix="--crispresso_command", doc=InputDocumentation(doc="CRISPResso command to call (default: CRISPResso)\n"))], outputs=[ToolOutput(tag="out_file_prefix", output_type=File(optional=True), selector=InputSelector(input_to_select="in_file_prefix", type_hint=File()), doc=OutputDocumentation(doc="File prefix for output plots and tables (default: )")), ToolOutput(tag="out_output_folder", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_output_folder", type_hint=File()), doc=OutputDocumentation(doc="Output folder to use for the analysis (default:\ncurrent folder) (default: )")), ToolOutput(tag="out_place_report_in_output_folder", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_place_report_in_output_folder", type_hint=File()), doc=OutputDocumentation(doc="If true, report will be written inside the CRISPResso\noutput folder. By default, the report will be written\none directory up from the report output. (default:\nFalse)")), ToolOutput(tag="out_batch_output_folder", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_batch_output_folder", type_hint=File()), doc=OutputDocumentation(doc="Directory where batch analysis output will be stored\n(default: None)"))], container="quay.io/biocontainers/crispresso2:2.1.0--py27h3dcb392_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Crispressobatch_V0_1_0().translate("wdl")

